==> core-1.0.1-20160614.135555-21-sources.jar: com/imcode/imcms/addon/imagearchive/Config.java <==
package com.imcode.imcms.addon.imagearchive;

import org.apache.commons.collections.BidiMap;

import java.io.File;

public class Config {
    private static File applicationPath;

    private File storagePath;
    private File tempPath;
    private File imageMagickPath;
    private String imcmsRootUrl;
    private String imcmsLoginUrlPath;
    private File imcmsImagesPath;
    private File imcmsLibrariesPath;
    private String imcmsUsersLibraryFolder;
    private File[] imcmsOldLibraryPaths;
    private BidiMap languages;

    private long maxImageUploadSize;
    private long maxZipUploadSize;

    private String accessCode;

    public Config() {
    }

    public String getAccessCode() {
        return accessCode;
    }

    public void setAccessCode(String accessCode) {
        this.accessCode = accessCode;
    }

    public long getMaxImageUploadSize() {
        return maxImageUploadSize;
    }

    public void setMaxImageUploadSize(long maxImageUploadSize) {
        this.maxImageUploadSize = maxImageUploadSize;
    }

    public long getMaxZipUploadSize() {
        return maxZipUploadSize;
    }

    public void setMaxZipUploadSize(long maxZipUploadSize) {
        this.maxZipUploadSize = maxZipUploadSize;
    }

    public String getImcmsRootUrl() {
        return imcmsRootUrl;
    }

    public void setImcmsRootUrl(String imcmsRootUrl) {
        this.imcmsRootUrl = imcmsRootUrl;
    }

    public File getStoragePath() {
        return storagePath;
    }

    public void setStoragePath(File storagePath) {
        this.storagePath = storagePath;
    }

    public File getTempPath() {
        return tempPath;
    }

    public void setTempPath(File tempPath) {
        this.tempPath = tempPath;
    }

    public File getImageMagickPath() {
        return imageMagickPath;
    }

    public void setImageMagickPath(File imageMagickPath) {
        this.imageMagickPath = imageMagickPath;
    }

    public String getImcmsLoginUrlPath() {
        return imcmsLoginUrlPath;
    }

    public void setImcmsLoginUrlPath(String imcmsLoginUrlPath) {
        this.imcmsLoginUrlPath = imcmsLoginUrlPath;
    }

    public File getImcmsImagesPath() {
        return imcmsImagesPath;
    }

    public void setImcmsImagesPath(File imcmsImagesPath) {
        this.imcmsImagesPath = imcmsImagesPath;
    }

    public File getImcmsLibrariesPath() {
        return imcmsLibrariesPath;
    }

    public void setImcmsLibrariesPath(File imcmsLibrariesPath) {
        this.imcmsLibrariesPath = imcmsLibrariesPath;
    }

    public String getImcmsUsersLibraryFolder() {
        return imcmsUsersLibraryFolder;
    }

    public void setImcmsUsersLibraryFolder(String imcmsUsersLibraryFolder) {
        this.imcmsUsersLibraryFolder = imcmsUsersLibraryFolder;
    }

    public File[] getImcmsOldLibraryPaths() {
        return imcmsOldLibraryPaths;
    }

    public void setImcmsOldLibraryPaths(File[] imcmsOldLibraryPaths) {
        this.imcmsOldLibraryPaths = imcmsOldLibraryPaths;
    }

    public BidiMap getLanguages() {
        return languages;
    }

    public void setLanguages(BidiMap languages) {
        this.languages = languages;
    }

    public static File getApplicationPath() {
        return applicationPath;
    }

    public static void setApplicationPath(File appPath) {
        applicationPath = appPath;
    }
}

==> core-1.0.2-20160922.071953-9-sources.jar: com/imcode/imcms/addon/imagearchive/Config.java <==
package com.imcode.imcms.addon.imagearchive;

import org.apache.commons.collections4.BidiMap;

import java.io.File;

public class Config {
    private static File applicationPath;

    private File storagePath;
    private File tempPath;
    private File imageMagickPath;
    private String imcmsRootUrl;
    private String imcmsLoginUrlPath;
    private File imcmsImagesPath;
    private File imcmsLibrariesPath;
    private String imcmsUsersLibraryFolder;
    private File[] imcmsOldLibraryPaths;
    private BidiMap<String, String> languages;

    private long maxImageUploadSize;
    private long maxZipUploadSize;

    private String accessCode;

    public Config() {
    }

    public String getAccessCode() {
        return accessCode;
    }

    public void setAccessCode(String accessCode) {
        this.accessCode = accessCode;
    }

    public long getMaxImageUploadSize() {
        return maxImageUploadSize;
    }

    public void setMaxImageUploadSize(long maxImageUploadSize) {
        this.maxImageUploadSize = maxImageUploadSize;
    }

    public long getMaxZipUploadSize() {
        return maxZipUploadSize;
    }

    public void setMaxZipUploadSize(long maxZipUploadSize) {
        this.maxZipUploadSize = maxZipUploadSize;
    }

    public String getImcmsRootUrl() {
        return imcmsRootUrl;
    }

    public void setImcmsRootUrl(String imcmsRootUrl) {
        this.imcmsRootUrl = imcmsRootUrl;
    }

    public File getStoragePath() {
        return storagePath;
    }

    public void setStoragePath(File storagePath) {
        this.storagePath = storagePath;
    }

    public File getTempPath() {
        return tempPath;
    }

    public void setTempPath(File tempPath) {
        this.tempPath = tempPath;
    }

    public File getImageMagickPath() {
        return imageMagickPath;
    }

    public void setImageMagickPath(File imageMagickPath) {
        this.imageMagickPath = imageMagickPath;
    }

    public String getImcmsLoginUrlPath() {
        return imcmsLoginUrlPath;
    }

    public void setImcmsLoginUrlPath(String imcmsLoginUrlPath) {
        this.imcmsLoginUrlPath = imcmsLoginUrlPath;
    }

    public File getImcmsImagesPath() {
        return imcmsImagesPath;
    }

    public void setImcmsImagesPath(File imcmsImagesPath) {
        this.imcmsImagesPath = imcmsImagesPath;
    }

    public File getImcmsLibrariesPath() {
        return imcmsLibrariesPath;
    }

    public void setImcmsLibrariesPath(File imcmsLibrariesPath) {
        this.imcmsLibrariesPath = imcmsLibrariesPath;
    }

    public String getImcmsUsersLibraryFolder() {
        return imcmsUsersLibraryFolder;
    }

    public void setImcmsUsersLibraryFolder(String imcmsUsersLibraryFolder) {
        this.imcmsUsersLibraryFolder = imcmsUsersLibraryFolder;
    }

    public File[] getImcmsOldLibraryPaths() {
        return imcmsOldLibraryPaths;
    }

    public void setImcmsOldLibraryPaths(File[] imcmsOldLibraryPaths) {
        this.imcmsOldLibraryPaths = imcmsOldLibraryPaths;
    }

    public BidiMap<String, String> getLanguages() {
        return languages;
    }

    public void setLanguages(BidiMap<String, String> languages) {
        this.languages = languages;
    }

    public static File getApplicationPath() {
        return applicationPath;
    }

    public static void setApplicationPath(File appPath) {
        applicationPath = appPath;
    }
}
